@@ -15,26 +15,20 @@ from sacn.messages.root_layer import \
 
 class SyncPacket(RootLayer):
     def __init__(self, cid: tuple, syncAddr: int, sequence: int = 0):
-        self._cid = cid
-        self._syncAddr = syncAddr
-        self._sequence = sequence
+        self.syncAddr = syncAddr
+        self.sequence = sequence
         super().__init__(49, cid, VECTOR_ROOT_E131_EXTENDED)
 
-    @RootLayer.cid.setter
-    def cid(self, cid: tuple):
-        if (len(cid) != 16 or not all(isinstance(x, int) for x in cid) or not all(0 <= x <= 255 for x in cid)):
-            raise TypeError(f'cid must be a 16 byte tuple! value was {cid}')
-        super().__init__(49, cid, VECTOR_ROOT_E131_EXTENDED)
-        self._cid = cid
-
     @property
     def syncAddr(self) -> int:
         return self._syncAddr
 
     @syncAddr.setter
     def syncAddr(self, sync_universe: int):
+        if type(sync_universe) is not int:
+            raise TypeError(f'sync_universe must be an integer! Type was {type(sync_universe)}')
         if sync_universe not in range(1, 64000):
-            raise TypeError(f'sync_universe must be [1-63999]! value was {sync_universe}')
+            raise ValueError(f'sync_universe must be [1-63999]! value was {sync_universe}')
         self._syncAddr = sync_universe
 
     @property
@@ -43,8 +37,10 @@ class SyncPacket(RootLayer):
 
     @sequence.setter
     def sequence(self, sequence: int):
+        if type(sequence) is not int:
+            raise TypeError('sequence must be an integer')
         if sequence not in range(0, 256):
-            raise TypeError(f'Sequence is a byte! values: [0-255]! value was {sequence}')
+            raise ValueError(f'sequence is a byte! values: [0-255]! value was {sequence}')
         self._sequence = sequence
 
     def sequence_increase(self):
@@ -52,7 +48,7 @@ class SyncPacket(RootLayer):
         if self._sequence > 0xFF:
             self._sequence = 0
 
-    def getBytes(self) -> tuple:
+    def getBytes(self) -> list:
         rtrnList = super().getBytes()
         rtrnList.extend(make_flagsandlength(self.length - 38))
         rtrnList.extend(VECTOR_E131_EXTENDED_SYNCHRONIZATION)
@@ -76,6 +72,6 @@ class SyncPacket(RootLayer):
            tuple(raw_data[40:44]) != tuple(VECTOR_E131_EXTENDED_SYNCHRONIZATION):
             # REMEMBER: when slicing: [inclusive:exclusive]
             raise TypeError('Some of the vectors in the given raw data are not compatible to the E131 Standard!')
-        tmpPacket = SyncPacket(cid=raw_data[22:38], syncAddr=byte_tuple_to_int(raw_data[45:47]))
+        tmpPacket = SyncPacket(cid=tuple(raw_data[22:38]), syncAddr=byte_tuple_to_int(raw_data[45:47]))
         tmpPacket.sequence = raw_data[44]
         return tmpPacket
